@@ -79,6 +79,7 @@ def iterate_structure(structure, iterations, origin=None):
 
     Examples
     --------
+    >>> from scipy import ndimage
     >>> struct = ndimage.generate_binary_structure(2, 1)
     >>> struct.astype(int)
     array([[0, 1, 0],
@@ -156,6 +157,7 @@ def generate_binary_structure(rank, connectivity):
 
     Examples
     --------
+    >>> from scipy import ndimage
     >>> struct = ndimage.generate_binary_structure(2, 1)
     >>> struct
     array([[False,  True, False],
@@ -342,7 +344,8 @@ def binary_erosion(input, structure=None, iterations=1, mask=None,
 
     Examples
     --------
-    >>> a = np.zeros((7,7), dtype=np.int)
+    >>> from scipy import ndimage
+    >>> a = np.zeros((7,7), dtype=int)
     >>> a[1:6, 2:5] = 1
     >>> a
     array([[0, 0, 0, 0, 0, 0, 0],
@@ -429,6 +432,7 @@ def binary_dilation(input, structure=None, iterations=1, mask=None,
 
     Examples
     --------
+    >>> from scipy import ndimage
     >>> a = np.zeros((5, 5))
     >>> a[2, 2] = 1
     >>> a
@@ -555,7 +559,8 @@ def binary_opening(input, structure=None, iterations=1, output=None,
 
     Examples
     --------
-    >>> a = np.zeros((5,5), dtype=np.int)
+    >>> from scipy import ndimage
+    >>> a = np.zeros((5,5), dtype=int)
     >>> a[1:4, 1:4] = 1; a[4, 4] = 1
     >>> a
     array([[0, 0, 0, 0, 0],
@@ -564,27 +569,27 @@ def binary_opening(input, structure=None, iterations=1, output=None,
            [0, 1, 1, 1, 0],
            [0, 0, 0, 0, 1]])
     >>> # Opening removes small objects
-    >>> ndimage.binary_opening(a, structure=np.ones((3,3))).astype(np.int)
+    >>> ndimage.binary_opening(a, structure=np.ones((3,3))).astype(int)
     array([[0, 0, 0, 0, 0],
            [0, 1, 1, 1, 0],
            [0, 1, 1, 1, 0],
            [0, 1, 1, 1, 0],
            [0, 0, 0, 0, 0]])
     >>> # Opening can also smooth corners
-    >>> ndimage.binary_opening(a).astype(np.int)
+    >>> ndimage.binary_opening(a).astype(int)
     array([[0, 0, 0, 0, 0],
            [0, 0, 1, 0, 0],
            [0, 1, 1, 1, 0],
            [0, 0, 1, 0, 0],
            [0, 0, 0, 0, 0]])
     >>> # Opening is the dilation of the erosion of the input
-    >>> ndimage.binary_erosion(a).astype(np.int)
+    >>> ndimage.binary_erosion(a).astype(int)
     array([[0, 0, 0, 0, 0],
            [0, 0, 0, 0, 0],
            [0, 0, 1, 0, 0],
            [0, 0, 0, 0, 0],
            [0, 0, 0, 0, 0]])
-    >>> ndimage.binary_dilation(ndimage.binary_erosion(a)).astype(np.int)
+    >>> ndimage.binary_dilation(ndimage.binary_erosion(a)).astype(int)
     array([[0, 0, 0, 0, 0],
            [0, 0, 1, 0, 0],
            [0, 1, 1, 1, 0],
@@ -660,7 +665,8 @@ def binary_closing(input, structure=None, iterations=1, output=None,
 
     Examples
     --------
-    >>> a = np.zeros((5,5), dtype=np.int)
+    >>> from scipy import ndimage
+    >>> a = np.zeros((5,5), dtype=int)
     >>> a[1:-1, 1:-1] = 1; a[2,2] = 0
     >>> a
     array([[0, 0, 0, 0, 0],
@@ -669,20 +675,20 @@ def binary_closing(input, structure=None, iterations=1, output=None,
            [0, 1, 1, 1, 0],
            [0, 0, 0, 0, 0]])
     >>> # Closing removes small holes
-    >>> ndimage.binary_closing(a).astype(np.int)
+    >>> ndimage.binary_closing(a).astype(int)
     array([[0, 0, 0, 0, 0],
            [0, 1, 1, 1, 0],
            [0, 1, 1, 1, 0],
            [0, 1, 1, 1, 0],
            [0, 0, 0, 0, 0]])
     >>> # Closing is the erosion of the dilation of the input
-    >>> ndimage.binary_dilation(a).astype(np.int)
+    >>> ndimage.binary_dilation(a).astype(int)
     array([[0, 1, 1, 1, 0],
            [1, 1, 1, 1, 1],
            [1, 1, 1, 1, 1],
            [1, 1, 1, 1, 1],
            [0, 1, 1, 1, 0]])
-    >>> ndimage.binary_erosion(ndimage.binary_dilation(a)).astype(np.int)
+    >>> ndimage.binary_erosion(ndimage.binary_dilation(a)).astype(int)
     array([[0, 0, 0, 0, 0],
            [0, 1, 1, 1, 0],
            [0, 1, 1, 1, 0],
@@ -690,7 +696,7 @@ def binary_closing(input, structure=None, iterations=1, output=None,
            [0, 0, 0, 0, 0]])
 
 
-    >>> a = np.zeros((7,7), dtype=np.int)
+    >>> a = np.zeros((7,7), dtype=int)
     >>> a[1:6, 2:5] = 1; a[1:3,3] = 0
     >>> a
     array([[0, 0, 0, 0, 0, 0, 0],
@@ -702,7 +708,7 @@ def binary_closing(input, structure=None, iterations=1, output=None,
            [0, 0, 0, 0, 0, 0, 0]])
     >>> # In addition to removing holes, closing can also
     >>> # coarsen boundaries with fine hollows.
-    >>> ndimage.binary_closing(a).astype(np.int)
+    >>> ndimage.binary_closing(a).astype(int)
     array([[0, 0, 0, 0, 0, 0, 0],
            [0, 0, 1, 0, 1, 0, 0],
            [0, 0, 1, 1, 1, 0, 0],
@@ -710,7 +716,7 @@ def binary_closing(input, structure=None, iterations=1, output=None,
            [0, 0, 1, 1, 1, 0, 0],
            [0, 0, 1, 1, 1, 0, 0],
            [0, 0, 0, 0, 0, 0, 0]])
-    >>> ndimage.binary_closing(a, structure=np.ones((2,2))).astype(np.int)
+    >>> ndimage.binary_closing(a, structure=np.ones((2,2))).astype(int)
     array([[0, 0, 0, 0, 0, 0, 0],
            [0, 0, 1, 1, 1, 0, 0],
            [0, 0, 1, 1, 1, 0, 0],
@@ -778,7 +784,8 @@ def binary_hit_or_miss(input, structure1=None, structure2=None,
 
     Examples
     --------
-    >>> a = np.zeros((7,7), dtype=np.int)
+    >>> from scipy import ndimage
+    >>> a = np.zeros((7,7), dtype=int)
     >>> a[1, 1] = 1; a[2:4, 2:4] = 1; a[4:6, 4:6] = 1
     >>> a
     array([[0, 0, 0, 0, 0, 0, 0],
@@ -794,7 +801,7 @@ def binary_hit_or_miss(input, structure1=None, structure2=None,
            [0, 1, 1],
            [0, 1, 1]])
     >>> # Find the matches of structure1 in the array a
-    >>> ndimage.binary_hit_or_miss(a, structure1=structure1).astype(np.int)
+    >>> ndimage.binary_hit_or_miss(a, structure1=structure1).astype(int)
     array([[0, 0, 0, 0, 0, 0, 0],
            [0, 0, 0, 0, 0, 0, 0],
            [0, 0, 1, 0, 0, 0, 0],
@@ -805,7 +812,7 @@ def binary_hit_or_miss(input, structure1=None, structure2=None,
     >>> # Change the origin of the filter
     >>> # origin1=1 is equivalent to origin1=(1,1) here
     >>> ndimage.binary_hit_or_miss(a, structure1=structure1,\\
-    ... origin1=1).astype(np.int)
+    ... origin1=1).astype(int)
     array([[0, 0, 0, 0, 0, 0, 0],
            [0, 0, 0, 0, 0, 0, 0],
            [0, 0, 0, 0, 0, 0, 0],
@@ -887,9 +894,10 @@ def binary_propagation(input, structure=None, mask=None,
 
     Examples
     --------
-    >>> input = np.zeros((8, 8), dtype=np.int)
+    >>> from scipy import ndimage
+    >>> input = np.zeros((8, 8), dtype=int)
     >>> input[2, 2] = 1
-    >>> mask = np.zeros((8, 8), dtype=np.int)
+    >>> mask = np.zeros((8, 8), dtype=int)
     >>> mask[1:4, 1:4] = mask[4, 4]  = mask[6:8, 6:8] = 1
     >>> input
     array([[0, 0, 0, 0, 0, 0, 0, 0],
@@ -909,7 +917,7 @@ def binary_propagation(input, structure=None, mask=None,
            [0, 0, 0, 0, 0, 0, 0, 0],
            [0, 0, 0, 0, 0, 0, 1, 1],
            [0, 0, 0, 0, 0, 0, 1, 1]])
-    >>> ndimage.binary_propagation(input, mask=mask).astype(np.int)
+    >>> ndimage.binary_propagation(input, mask=mask).astype(int)
     array([[0, 0, 0, 0, 0, 0, 0, 0],
            [0, 1, 1, 1, 0, 0, 0, 0],
            [0, 1, 1, 1, 0, 0, 0, 0],
@@ -919,7 +927,7 @@ def binary_propagation(input, structure=None, mask=None,
            [0, 0, 0, 0, 0, 0, 0, 0],
            [0, 0, 0, 0, 0, 0, 0, 0]])
     >>> ndimage.binary_propagation(input, mask=mask,\\
-    ... structure=np.ones((3,3))).astype(np.int)
+    ... structure=np.ones((3,3))).astype(int)
     array([[0, 0, 0, 0, 0, 0, 0, 0],
            [0, 1, 1, 1, 0, 0, 0, 0],
            [0, 1, 1, 1, 0, 0, 0, 0],
@@ -930,7 +938,7 @@ def binary_propagation(input, structure=None, mask=None,
            [0, 0, 0, 0, 0, 0, 0, 0]])
 
     >>> # Comparison between opening and erosion+propagation
-    >>> a = np.zeros((6,6), dtype=np.int)
+    >>> a = np.zeros((6,6), dtype=int)
     >>> a[2:5, 2:5] = 1; a[0, 0] = 1; a[5, 5] = 1
     >>> a
     array([[1, 0, 0, 0, 0, 0],
@@ -939,7 +947,7 @@ def binary_propagation(input, structure=None, mask=None,
            [0, 0, 1, 1, 1, 0],
            [0, 0, 1, 1, 1, 0],
            [0, 0, 0, 0, 0, 1]])
-    >>> ndimage.binary_opening(a).astype(np.int)
+    >>> ndimage.binary_opening(a).astype(int)
     array([[0, 0, 0, 0, 0, 0],
            [0, 0, 0, 0, 0, 0],
            [0, 0, 0, 1, 0, 0],
@@ -954,7 +962,7 @@ def binary_propagation(input, structure=None, mask=None,
            [0, 0, 0, 1, 0, 0],
            [0, 0, 0, 0, 0, 0],
            [0, 0, 0, 0, 0, 0]])
-    >>> ndimage.binary_propagation(b, mask=a).astype(np.int)
+    >>> ndimage.binary_propagation(b, mask=a).astype(int)
     array([[0, 0, 0, 0, 0, 0],
            [0, 0, 0, 0, 0, 0],
            [0, 0, 1, 1, 1, 0],
@@ -1013,6 +1021,7 @@ def binary_fill_holes(input, structure=None, output=None, origin=0):
 
     Examples
     --------
+    >>> from scipy import ndimage
     >>> a = np.zeros((5, 5), dtype=int)
     >>> a[1:4, 1:4] = 1
     >>> a[2,2] = 0
@@ -1117,7 +1126,8 @@ def grey_erosion(input, size=None, footprint=None, structure=None,
 
     Examples
     --------
-    >>> a = np.zeros((7,7), dtype=np.int)
+    >>> from scipy import ndimage
+    >>> a = np.zeros((7,7), dtype=int)
     >>> a[1:6, 1:6] = 3
     >>> a[4,4] = 2; a[2,3] = 1
     >>> a
@@ -1226,7 +1236,8 @@ def grey_dilation(input, size=None, footprint=None, structure=None,
 
     Examples
     --------
-    >>> a = np.zeros((7,7), dtype=np.int)
+    >>> from scipy import ndimage
+    >>> a = np.zeros((7,7), dtype=int)
     >>> a[2:5, 2:5] = 1
     >>> a[4,4] = 2; a[2,3] = 3
     >>> a
@@ -1361,6 +1372,7 @@ def grey_opening(input, size=None, footprint=None, structure=None,
 
     Examples
     --------
+    >>> from scipy import ndimage
     >>> a = np.arange(36).reshape((6,6))
     >>> a[3, 3] = 50
     >>> a
@@ -1441,6 +1453,7 @@ def grey_closing(input, size=None, footprint=None, structure=None,
 
     Examples
     --------
+    >>> from scipy import ndimage
     >>> a = np.arange(36).reshape((6,6))
     >>> a[3,3] = 0
     >>> a
@@ -1526,7 +1539,8 @@ def morphological_gradient(input, size=None, footprint=None,
 
     Examples
     --------
-    >>> a = np.zeros((7,7), dtype=np.int)
+    >>> from scipy import ndimage
+    >>> a = np.zeros((7,7), dtype=int)
     >>> a[2:5, 2:5] = 1
     >>> ndimage.morphological_gradient(a, size=(3,3))
     array([[0, 0, 0, 0, 0, 0, 0],
@@ -1547,7 +1561,7 @@ def morphological_gradient(input, size=None, footprint=None,
            [0, 1, 1, 1, 1, 1, 0],
            [0, 1, 1, 1, 1, 1, 0],
            [0, 0, 0, 0, 0, 0, 0]])
-    >>> a = np.zeros((7,7), dtype=np.int)
+    >>> a = np.zeros((7,7), dtype=int)
     >>> a[2:5, 2:5] = 1
     >>> a[4,4] = 2; a[2,3] = 3
     >>> a
@@ -2042,12 +2056,12 @@ def distance_transform_edt(input, sampling=None,
 
     Examples
     --------
-    >>> a = np.array(([0,1,1,1,1],
-                      [0,0,1,1,1],
-                      [0,1,1,1,1],
-                      [0,1,1,1,0],
-                      [0,1,1,0,0]))
     >>> from scipy import ndimage
+    >>> a = np.array(([0,1,1,1,1],
+    ...               [0,0,1,1,1],
+    ...               [0,1,1,1,1],
+    ...               [0,1,1,1,0],
+    ...               [0,1,1,0,0]))
     >>> ndimage.distance_transform_edt(a)
     array([[ 0.    ,  1.    ,  1.4142,  2.2361,  3.    ],
            [ 0.    ,  0.    ,  1.    ,  2.    ,  2.    ],
